@@ -276,12 +276,17 @@ def _check_access_account_lgq(google_ads_account_id: str, google_ads_client: Goo
             raise GoogleAdsAccountException(
                 f"We cannot find this account ({google_ads_account_id}). Are you sure you entered the correct id?")
         customer_resp = customers[0]
-    except (GoogleAdsException, GoogleAdsAccountException) as err:
+    except GoogleAdsException as err:
         if "USER_PERMISSION_DENIED" in str(err):
             raise GoogleAdsAccountNoAccessException
-        else:
+        elif "INVALID_CUSTOMER_ID" in str(err):
+            raise GoogleAdsAccountException(
+                f"Invalid account id ({google_ads_account_id}). Are you sure you entered the correct id?"
+            )
+        elif "CUSTOMER_NOT_FOUND" in str(err):
             raise GoogleAdsAccountException(
                 f"We cannot find this account ({google_ads_account_id}). Are you sure you entered the correct id?")
+        raise
     if customer_resp.customer.manager:
         raise GoogleAdsAccountException(
             'This account ID is a MCC. Please enter a Google Ads Account.')
